---
title: 포트원 추천패키지
category: 포트원 이용절차 (온보딩 가이드) > 추천패키지 > 추천패키지
seo:
  title: 포트원 추천패키지
  description: >-
    포트원이 추천하는 결제 패키지 안내입니다. 신용카드 일반결제, 신용카드 정기결제, 간편결제, 본인인증으로 구성되어 있습니다. Q&A를
    통해 고객님들이 가장 많이 물어보시는 정보까지 확인해보세요.
  keywords:
    - 추천패키지
tags:
  - 공통
  - 추천서비스
pgCompanies:
  - 공통
searchTags:
  - KPN
  - 무료
  - 많이쓰는PG
  - PG추천
  - PG사 추천
  - 패키지
  - 전자결제신청방법
  - 추천PG
  - 추천패키지
---

### **신용카드 일반결제**

**일반결제**는 신용카드, 실시간 계좌이체, 가상계좌 수단을 기본적으로 포함하는 인증 결제방식과 동시에 일회성 결제임을 의미합니다. 추천 패키지의 \[신용카드 일반결제]는 이 중 신용카드 결제수단을 대표적으로 지원하는 결제대행사를 의미합니다.

쇼핑몰에서 가장 일반적으로 사용되는 방식이며 결제대행사(PG사)의 결제창을 띄운 뒤 원하는 카드사를 선택하여 앱 카드 · ISP 등으로 인증 과정을 거치는 방식입니다. 사업자는 고객의 결제정보를 보관하지 않기 때문에 고객은 구매를 원할 때마다 결제를 시도해야합니다.

신용카드 일반결제 를 지원하는 결제대행사 중 포트원에서 추천드리는 곳은 <Highlight text="&quot;한국결제네트웍스(KPN)&quot;" /> 입니다.

<Callout icon="" title="일반결제 가이드 자세히 보러가기↗" />



### **신용카드 정기결제**

정기결제는 반복적인 구독결제를 위해 최초 1회 카드정보를 등록하여 저장 후, 결제하는 방식을 의미합니다.

최초 1회만 고객이 결제정보를 등록하면 이후부터는 고객의 인증 없이도 고객사에서 원하는 때에 결제를 요청할 수 있습니다. .

<Callout icon="" title="정기결제 가이드 자세히 보러가기↗ " />

### **간편결제**

간편결제사에 가입되어있는 고객이라면, 해당 간편결제에 등록된 결제수단으로 결제가 가능한 방식입니다.예를 들면, 카카오페이에 이미 국민카드를 등록해놓은 고객이라면, 카카오페이를 통해 생체인증 혹은 비밀번호 인증만으로 국민카드 결제가 가능합니다. 포트원에서 추천드리는 간편결제사는 ‘**네이버페이**’와 ‘**카카오페이**’입니다.

<Callout icon="" title="간편결제 가이드 자세히 보러가기↗" />

### **본인인증**

본인임을 확인할 수 있는 인증서비스로 결제와 무관하게 인증절차가 필요할 때 사용되며 별도 가입이 필요한 서비스입니다. 보통 회원가입을 진행하는 단계에 도입하거나, 나이 제한 등의 서비스 제한이 필요할 경우 연동하여 사용합니다. 포트원에서 추천드리는 PG사는 ‘**다날**’ 입니다.\
※ 결제대행사 다날에서 제공하는 휴대폰 본인인증과 인증서비스가 상이하오니 자세한 사항은 아래 서비스 상세가이드를 참조해주시기 바랍니다.

<Callout icon="" title="본인인증 가이드 자세히 보러가기↗" />

### **QnA**

###### **1. 추천 패키지에 원하는 PG사와 결제수단이 노출되지 않습니다.**

- 신용카드 정기결제 ‘결제창 방식’ 지원 PG사와 같이 추천패키지에 노출되지 않는 서비스는 ‘전자결제 직접 선택하기' 버튼을 클릭하여 원하는 결제대행사 및 결제수단을 직접 선택하여 신청하실 수 있습니다.

<Callout title="전자결제 신청방법 보러가기 ↗" content="" />

**2. 결제대행사의 ‘허브형 간편결제’는 어떻게 신청하나요?**

- 우측 ‘전자결제 직접 선택하기’  > 간편결제 탭의 ‘허브형’으로 표기되어있는 결제대행사로 신청 가능합니다.

<Callout title="허브형 간편결제 지원하는 결제대행사 보러가기 ↗" />

<Callout content="결제대행사에 따라 허브형 간편결제용 PG상점아이디를 추가로 발급할 수 있습니다.
이런 경우 결제연동시 추가 발급된 PG상점아이디로 호출되도록 구현하시기 바랍니다." title="참고사항" icon="💡" />



**3. 휴대폰 소액결제의 정기결제는 어떻게 신청하나요?**

- 우측 ‘전자결제 직접 선택하기’ 버튼 > 휴대폰결제 - 정기결제를 지원하는 결제대행사 선택 > ‘휴대폰 소액결제 정기결제’ 클릭 후 신청 가능합니다.



**4. ‘일반 결제대행사’에서 제공하는 해외 결제 서비스는 어떻게 신청하나요?**

- 우측 ‘전자결제 직접 선택하기’ 버튼 > 일반결제에서 해외결제를 지원하는 결제대행사 선택 후 ‘신용카드 일반결제’로 신청 가능합니다. 이후, 결제대행사사측에 ‘해외카드’서비스 이용을 별도 요청하시어 계약 진행을 하시기 바랍니다.

5\. 추천패키지 신청 고객사에 제공되는 제휴혜택이 있나요?

- 포트원이 추천해드리는 결제대행사 추천패키지를 선택하시면 해당 결제대행사와 계약을 맺으실 때도 가입비 및 연 관리비가 모두 면제 처리 됩니다
- 포트원 추천패키지를 통해 결제대행사(PG사) 계약을 완료한 고객사에는 AWS 크레디트 제공, Salesfroce(세일즈포스) 특별할인가, 메일링 서비스 Stibee(스티비) 요금제 할인코드 서비스까지 특별 제휴혜택을 제공합니다.
- 클라우드부터 알림톡 서비스까지 스타트업 운영에 필요한 다양한 혜택까지 포트원과 함께하세요!

<Callout title="포트원 제휴혜택 보러가기 ↗" />
